CREATE TABLE Land (
       LCODE Number(4),
       MANZ NUMBER(4) NOT NULL,
       SPRACHE VARCHAR2(56) NOT NULL,
       CONSTRAINT pk_land PRIMARY KEY(LCODE)
);

CREATE TABLE Projekt (
       PNR Number(4),
       NAME VARCHAR2(32) NOT NULL,
       BUDGET NUMBER(10) NOT NULL,
       SPRACHE VARCHAR2(56) NOT NULL,
       CONSTRAINT pk_projekt PRIMARY KEY(PNR)
);

CREATE TABLE Sonderprojekt (
       PNR Number(4),
       SPONSOR VARCHAR2(56) NOT NULL,
       CONSTRAINT pk_sonderprojekt PRIMARY KEY(PNR),
       CONSTRAINT fk_sonderprojekt_projekt FOREIGN KEY(PNR) REFERENCES Projekt(PNR)
);

CREATE TABLE Meeting (
       MNR NUMBER(4),
       DATUM DATE,
       VON VARCHAR2(5),
       BIS VARCHAR2(5), 
       CONSTRAINT pk_meeting PRIMARY KEY(MNR)
);

CREATE TABLE Unterlage (
       MNR Number(4),
       ULINK VARCHAR2(56) NOT NULL,
       CONSTRAINT pk_unterlage PRIMARY KEY(MNR),
       CONSTRAINT fk_unterlage_meeting FOREIGN KEY(MNR) REFERENCES Meeting(MNR)
);

CREATE TABLE Aufgabenbereich (
       BEZEICHNUNG VARCHAR2(56) NOT NULL,
       CONSTRAINT pk_aufgabenbereich PRIMARY KEY(BEZEICHNUNG)
);

CREATE TABLE Mitarbeiter (
       PNR NUMBER(4),
       Name VARCHAR2(34) NOT NULL,
       BEZIRK NUMBER(4),
       SEIT DATE,
       DURCHWAHL NUMBER(12),
       GEHALT NUMBER(5),
       VORGESETZTER NUMBER(4) NOT NULL,
       CONSTRAINT pk_mitarbeiter PRIMARY KEY(PNR),
       CONSTRAINT fk_mitarbeiter_mitarbeiter FOREIGN KEY(VORGESETZTER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE Team (
       TEAMNR NUMBER(4),
       NAME VARCHAR2(56) NOT NULL,
       LEITER NUMBER(4) NOT NULL,
       CONSTRAINT pk_team PRIMARY KEY(TEAMNR),
       CONSTRAINT fk_team_mitarbeiter FOREIGN KEY(LEITER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE Abteilung (
       KNR NUMBER(4),
       NAME VARCHAR2(56) NOT NULL,
       LEITER NUMBER(4) NOT NULL,
       CONSTRAINT pk_abteilung PRIMARY KEY(KNR),
       CONSTRAINT fk_abteilung_mitarbeiter FOREIGN KEY(LEITER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE Schulung (
       DATUM DATE,
       THEMA VARCHAR2(56),
       PREIS NUMBER(12),
       CONSTRAINT pk_schulung PRIMARY KEY(DATUM, THEMA)
);

CREATE TABLE prj_land (
       LCODE Number(4),
       PNR Number(4),
       CONSTRAINT pk_prj_land PRIMARY KEY(LCODE, PNR)
);

CREATE TABLE hat_in (
       PROJEKT NUMBER(4),
       AUFGABENBEREICH VARCHAR2(56),
       MITARBEITER NUMBER(4),
       CONSTRAINT pk_hat_in PRIMARY KEY(PROJEKT, AUFGABENBEREICH, MITARBEITER),
       CONSTRAINT fk_hat_in_projekt FOREIGN KEY(PROJEKT) REFERENCES Projekt(PNR),
       CONSTRAINT fk_hat_in_aufgabenbereich FOREIGN KEY(AUFGABENBEREICH) REFERENCES Aufgabenbereich(BEZEICHNUNG),
       CONSTRAINT fk_hat_in_mitarbeiter FOREIGN KEY(MITARBEITER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE ma_team (
       TEAM NUMBER(4),
       MITARBEITER NUMBER(4),
       SEIT DATE NOT NULL,
       CONSTRAINT pk_in PRIMARY KEY(TEAM, MITARBEITER),
       CONSTRAINT fk_in_team FOREIGN KEY(TEAM) REFERENCES Team(TEAMNR),
       CONSTRAINT fk_in_mitarbeiter FOREIGN KEY(MITARBEITER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE nimmt_teil (
       MEETING NUMBER(4),
       MITARBEITER NUMBER(4),
       CONSTRAINT pk_nimmt_teil PRIMARY KEY(MITARBEITER, MEETING),
       CONSTRAINT fk_nimmt_teil_meeting FOREIGN KEY(MEETING) REFERENCES Meeting(MNR),
       CONSTRAINT fk_nimmt_teil_mitarbeiter FOREIGN KEY(MITARBEITER) REFERENCES Mitarbeiter(PNR)
);

CREATE TABLE besucht (
       MITARBEITER NUMBER(4),
       DATUM DATE,
       THEMA VARCHAR2(56),
       CONSTRAINT fk_besucht_mitarbeiter FOREIGN KEY(MITARBEITER) REFERENCES Mitarbeiter(PNR),
       CONSTRAINT fk_besucht_schulung FOREIGN KEY(DATUM,THEMA) REFERENCES Schulung(DATUM,THEMA),
       CONSTRAINT pk_besucht PRIMARY KEY(MITARBEITER, DATUM, THEMA)
);


CREATE TABLE arbeitet_an (
       PROJEKT NUMBER(4),
       TEAM NUMBER(4),
       CONSTRAINT pk_arbeitet_an PRIMARY KEY(PROJEKT, TEAM),
       CONSTRAINT fk_arbeitet_an_projekt FOREIGN KEY(PROJEKT) REFERENCES Projekt(PNR),
       CONSTRAINT fk_arbeitet_an_team FOREIGN KEY(TEAM) REFERENCES Team(TEAMNR)
);

CREATE TABLE arbeitet_fuer (
       ABTEILUNG NUMBER(4),
       TEAM NUMBER(4),
       CONSTRAINT pk_arbeitet_fuer PRIMARY KEY(ABTEILUNG, TEAM),
       CONSTRAINT fk_arbeitet_fuer_abteilung FOREIGN KEY(ABTEILUNG) REFERENCES Abteilung(KNR),
       CONSTRAINT fk_arbeitet_fuer_team FOREIGN KEY(TEAM) REFERENCES Team(TEAMNR)
);

CREATE TABLE proj_meeting (
       MEETING NUMBER(4), 
       PROJEKT NUMBER(4) NOT NULL,
       CONSTRAINT pk_proj_meeting PRIMARY KEY(MEETING),
       CONSTRAINT fk_proj_meeting_meeting FOREIGN KEY(MEETING) REFERENCES Meeting(MNR),
       CONSTRAINT fk_proj_meeting_projekt FOREIGN KEY(PROJEKT) REFERENCES Projekt(PNR)
);